==> json_stream_reader-0.1.0.tar.gz: json_stream_reader-0.1.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=6.0', ]

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest', ]

setup(
    author="Matt Chapman",
    author_email='matt@ninjitsuweb.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="Given a byte stream of {}-bracketed objects, generate one object-string at a time.",
    entry_points={
        'console_scripts': [
            'json_stream_reader=json_stream_reader.cli:main',
        ],
    },
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='json_stream_reader',
    name='json_stream_reader',
    packages=find_packages(include=['json_stream_reader']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/matt2000/json_stream_reader',
    version='0.1.0',
    zip_safe=False,
)

==> json_stream_reader-0.2.0.tar.gz: json_stream_reader-0.2.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=6.0', 'mypy']

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest',]

setup(
    author="Matt Chapman",
    author_email='matt@ninjitsuweb.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="Given a byte stream of {}-bracketed objects, generate one object-string at a time.",
    entry_points={
        'console_scripts': [
            'json_stream_reader=json_stream_reader.cli:main',
        ],
    },
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='json_stream_reader',
    name='json_stream_reader',
    packages=find_packages(include=['json_stream_reader']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/matt2000/json_stream_reader',
    version='0.2.0',
    zip_safe=False,
)
